
/*  -*- MaTX -*-
 *
 *  【名前】
 *      asin() - 逆正弦
 *
 *  【形式】
 *      y = asin(x)
 *         (Real   |Real|Complex) y;
 *         (Integer|Real|Complex) x;
 *
 *      Y = asin(X)
 *         Array Y;
 *         Array X;
 *
 *  【機能説明】
 *      asin(x)は，スカラ型(整数, 実数, 複素数) x の逆正弦を求める。
 *      角度はラジアンで計算される。x が実数のとき，
 *
 *          -1 <= x <= 1
 *
 *      の範囲に対し，asin(x) は
 *
 *          -PI/2 <= asin(x) <= PI/2
 *
 *      の範囲の実数となる。
 *	    asin(X)は，配列 X の各成分の逆正弦からなる配列 Y を求める。
 *      Y の大きさは X の大きさと同じ。
 *
 *  【アルゴリズム】
 *      i = (0,1)
 *      asin(z) = - i*log(i*z + sqrt(1 - z*z))
 *
 *  【例題】
 *      >> y = asin(0.5)
 *      y = 0.523599
 *
 *      範囲 -1 <= x <= 1 のasin(x)のグラフを表示する。
 *
 *      >> x = [-1:0.05:1];
 *      >> mgplot(1, x, asin(x), {"asin(x)"});
 *
 *  【関連項目】
 *      acos(), atan(), asinh(), acosh(), atanh()
 */
