
/*  -*- MaTX -*-
 *
 *  【名前】
 *      atan2() - 4 象限表現の逆正接
 *
 *  【形式】
 *      p = atan2(y, x)
 *         (Real   |Real) p;
 *         (Integer|Real) x, y;
 *
 *      P = atan2(Y, X)
 *         Array P;
 *         Array X, Y;
 *
 *  【機能説明】
 *      atan2(y, x)は，スカラ型(整数, 実数) y と x の逆正接を 4 象限
 *      表現で求める。角度はラジアンで計算される。atan2(y, x) の結果は
 *
 *          -PI <= atan2(y, x) <= PI
 *
 *      の範囲の実数となる。
 *	    atan2(Y, X)は，配列 Y と X の各成分の 4 象限表現の逆正接から
 *      なる配列 P を求める。P の大きさは X の大きさと同じ。X と Y の
 *      大きさは一致しなければならい。
 *
 *      atan2(y,x) と atan(y/x) の違いは，atan(y/x) の範囲が[-PI/2, PI/2]
 *      であることである。
 *
 *  【例題】
 *      >> y = atan2(1, 1)
 *      y = 0.785398 (= PI/4)
 *
 *      複素数 z = (x, y) の極座標は
 *
 *      >> r = abs(z);
 *      >> theta = atan2(Im(z), Re(z));
 *
 *     で求まる。このとき，z は
 *
 *      >> r * exp((0,1)*theta)
 *
 *     と一致する。
 *
 *  【関連項目】
 *      asin(), acos(), atan()
 */
