
/*  -*- MaTX -*-
 *
 *  【名前】
 *      fft() - 高速フーリエ変換
 *
 *  【形式】
 *      Y = fft(X)
 *         (CoMatrix|CoArray) Y;
 *         (Matrix|Array) X;
 *
 *      Y = fft(X,k)
 *         (CoMatrix|CoArray) Y;
 *         (Matrix|Array) X;
 *         Integer k;
 *
 *  【機能説明】
 *      fft(X)は，2 のべき乗の長さのベクトル X について，基底が 2 の
 *      高速フーリエ変換を計算する。fft(X,k) は k 点の高速フーリエ変換
 *      をする。X の長さが k より短いとき，ゼロが後ろに付け加えられ，
 *      X の長さが k より長いとき，k 番目以降が切り捨てられる。
 *
 *  【例題】
 *      正規白色雑音の中に隠された 50 Hz と 120 Hz の信号を見つけ出す。
 *
 *      t = [0:0.001:0.6];
 *      x = sin(2*PI*50*t) + sin(2*PI*120*t);
 *      y = x + 2*randn(t);
 *      Y = fft(y,512);
 *      Pyy = Re(Y * conj(Y))/512;
 *      f = 1000*[0:255]/512;
 *      mgplot(1,f,Pyy(1:256));
 *
 *  【関連項目】
 *      fft_row(), fft_col()
 */
