
/*  -*- MaTX -*-
 *
 *  【名前】
 *      fix() - ゼロ方向への丸め
 *
 *  【形式】
 *      y = fix(x)
 *         (Real|Complex|Polynomial|Rational) y;
 *         (Real|Complex|Polynomial|Rational) x;
 *
 *      Y = fix(X)
 *         (Matrix|Array|Index) Y;
 *         (Matrix|Array|index) X;
 *
 *  【機能説明】
 *      実数 x について，fix(x)は，x をゼロ方向に最も近い整数に丸める。
 *      複素数 x について，fix(x) は，x の実部と虚部をそれぞれゼロ方向に
 *      最も近い整数に丸める。(多項式|有理多項式) x にについて，fix(x) は，
 *      x の各係数をゼロ方向に最も近い整数に丸める。
 *
 *	    fix(X)は，(行列|配列|指数) X の各成分に fix(X(i,j)) を作用した
 *      結果からなる(行列|配列|指数) を求める。Y の大きさは X の大きさと
 *      同じになる。
 *
 *  【例題】
 *      >> y = fix(3.14)
 *      y = 3
 *      >> y = fix((3.14, -2.6))
 *      y = (3,-2)
 *      >> s = Polynomial("s");
 *      >> y = fix(2.1*s - 3.6)
 *      y = 2 s - 3
 *      >> Y = fix([1.2, -3.4, 5.6])
 *      === [Y] : (  1,  3) ===
 *                 (  1)           (  2)           (  3)     
 *      (  1)  1.00000000E+00 -3.00000000E+00  5.00000000E+00
 *
 *  【関連項目】
 *      fix(), floor(), ceil(), round(),
 */
