
/*  -*- MaTX -*-
 *
 *  【名前】
 *      floor() - 負の無限大方向への丸め
 *
 *  【形式】
 *      y = floor(x)
 *         (Real|Complex|Polynomial|Rational) y;
 *         (Real|Complex|Polynomial|Rational) x;
 *
 *      Y = floor(X)
 *         (Matrix|Array|Index) Y;
 *         (Matrix|Array|index) X;
 *
 *  【機能説明】
 *      実数 x について，floor(x)は，x を負の無限大方向に最も近い整数に
 *      丸める。複素数 x について，floor(x) は，x の実部と虚部をそれぞれ
 *      負の無限大方向に最も近い整数に丸める。(多項式|有理多項式) x に
 *      について，floor(x) は，x の各係数を負の無限大方向に最も近い整数に
 *      丸める。
 *
 *	    floor(X)は，(行列|配列|指数) X の各成分に floor(X(i,j)) を作用した
 *      結果からなる(行列|配列|指数) を求める。Y の大きさは X の大きさと
 *      同じになる。
 *
 *  【例題】
 *      >> y = floor(3.14)
 *      y = 3
 *      >> y = floor((3.14, 2.5))
 *      y = (3,2)
 *      >> s = Polynomial("s");
 *      >> y = floor(2.1*s + 3.2)
 *      y = 2s + 3
 *      >> Y = floor([1.2 3.4 5.6])
 *      === [Y] : (  1,  3) ===
 *                 (  1)           (  2)           (  3)     
 *      (  1)  1.00000000E+00  3.00000000E+00  5.00000000E+00
 *
 *  【関連項目】
 *      fix(), ceil(), round(), round2z(),
 */
