
/*  -*- MaTX -*-
 *
 *  【名前】
 *      socket_read - TCPソケットからバイナリデータを読み込む
 *
 *  【形式】
 *      X = socket_read(sockfd, count, type)
 *         Matrix X;
 *         Integer sockfd;
 *         Integer count;
 *         String type;
 *
 *      X = socket_read(sockfd, count, type, endian)
 *         Matrix X;
 *         Integer sockfd;
 *         Integer count;
 *         String type;
 *         Integer endian;
 *
 *  【機能説明】
 *      socket_read(sockfd, count, type) は指定したTCPソケットから
 *      バイナリデータを読み込み，それを成分とする行ベクトルを返す。
 *      読み込みに失敗すると，空行列を返す。
 *      sockfd は socket_open() あるいは socket_accept() が返すソケット
 *      ディスクリプタ，count は読み込むデータ数，type は読み込むデータの
 *      型である。type には，C言語のデータの型を文字列で指定する。
 *      次に指定できる型を示す。ただし，システムによって符合あり(signed)の
 *      型を指定できない場合がある。
 *
 *      socket_read は，データの読込みに失敗すると，0x0 の行列を返す。失敗の
 *      原因としては，ソケット端のプロセスに指定個数のデータが存在しない，
        ソケットから正常にデータを読めない，が考えられる。
 *
 *      "char"           : 文字 (8 bits)
 *      "signed char"    : 符合あり文字 (8 bits)
 *      "unsigned char"  : 符合なし文字 (8 bits)
 *      "short"          : 整数 (16 bits)
 *      "signed short"   : 符合あり整数 (16 bits)
 *      "unsigned short" : 符合なし整数 (16 bits)
 *      "int"            : 整数 (16,32,64 bits)
 *      "signed int"     : 符合あり整数 (16,32,64 bits)
 *      "unsigned int"   : 符合なし整数 (16,32,64 bits)
 *      "long"           : 整数 (32 bits)
 *      "signed long"    : 符合あり整数 (32 bits)
 *      "unsigned long"  : 符合なし整数 (32 bits)
 *      "float"          : 単精度浮動小数点数 (32 bits)
 *      "double"         : 倍精度浮動小数点数 (64 bits)
 *
 *      socket_read(sockfd, count, type, 1)は，バイナリデータの
 *      数値形式(Endian)を変更する。
 *
 *  【例題】
 *      5 個の int 型のバイナリデータを読み込む。
 *
 *      sockfd = socket_open("TCP");
 *      socket_connect(sockfd, port, "server");
 *      B = socket_read(sockfd, 5, "int");
 *      socket_close(sockfd);  
 *
 *      3 個の double 型のバイナリデータをEndianを変更し，読み込む。
 *
 *      sockfd = socket_open("TCP");
 *      socket_connect(sockfd, port, "server");
 *      C = socket_read(sockfd, 3, "double", 1);
 *      socket_close(sockfd);
 *  
 *  【関連項目】
 *      fread, socket_open, socket_write
 */
