
/*  -*- MaTX -*-
 *
 *  【名前】
 *      socket_write - 行列をソケットにバイナリデータとして書き込む
 *
 *  【形式】
 *      count = socket_write(sockfd, X, type)
 *         Integer count;
 *         Integer sockfd;
 *         (Matrix|Array|Index) X;
 *         String type;
 *
 *  【機能説明】
 *      socket_write(sockfd, mat, type) は行列の成分を指定したソケットに指定
 *      したデータ型のバイナリで書き込む。データは行の順に書き込まれる。
 *      sockfd は関数 socket_open() あるいは socket_accept() が返すソケット
 *      ディスクリプタ，X は書き込む行列，type は書き込むデータの型である。
 *      type には次に示す C 言語のデータの型を文字列で指定する。
 *
 *      "char"           : 文字 (8 bits)
 *      "signed char"    : 符合あり文字 (8 bits)
 *      "unsigned char"  : 符合なし文字 (8 bits)
 *      "short"          : 整数 (16 bits)
 *      "signed short"   : 符合あり整数 (16 bits)
 *      "unsigned short" : 符合なし整数 (16 bits)
 *      "int"            : 整数 (16,32,64 bits)
 *      "signed int"     : 符合あり整数 (16,32,64 bits)
 *      "unsigned int"   : 符合なし整数 (16,32,64 bits)
 *      "long"           : 整数 (32 bits)
 *      "signed long"    : 符合あり整数 (32 bits)
 *      "unsigned long"  : 符合なし整数 (32 bits)
 *      "float"          : 単精度浮動小数点数 (32 bits)
 *      "double"         : 倍精度浮動小数点数 (64 bits)
 *
 *  【例題】
 *      行列 A を int 型のバイナリデータとしてソケットに送信する。
 *
 *      A = [1 2 3 4 5];
 *      sockfd = socket_open("TCP");
 *      socket_connect(sockfd);
 *      socket_write(sockfd, A, "int");
 *      socket_close(sockfd);
 *  
 *  【関連項目】
 *      fwrite, socket_read
 */
